@@ -164,7 +164,7 @@ def update_sql(
     assignments: Constraints,
     constraints: Constraints = None,
     *,
-    timestamp_col: str = "updated_at",
+    timestamp_col: Optional[str] = "updated_at",
     returning: str = None
 ) -> SQL:
     """Generates an update statement.
@@ -180,7 +180,8 @@ def update_sql(
             raise Exception(
                 "Cannot combine timestamp_col and TextConstraint for update"
             )
-        elif isinstance(assignments, DictConstraint):
+
+        if isinstance(assignments, DictConstraint):
             assignments[timestamp_col] = Literal("now()")
         elif isinstance(assignments, BinaryConstraint):
             assignments = [
