@@ -1,7 +1,7 @@
 """Contains the DB wrapper class."""
 from contextlib import asynccontextmanager
 from logging import Logger, getLogger
-from typing import Any, AsyncIterator, Callable, List, Optional, cast
+from typing import Any, AsyncIterator, Callable, Iterable, List, Optional, cast
 
 from asyncpg import Connection, connect
 
@@ -113,7 +113,7 @@ class DBBase:
         else:
             await self.conn.execute(sql)
 
-    async def executemany(self, sql: str, params: List[List[Any]] = None):
+    async def executemany(self, sql: str, params: List[Iterable[Any]] = None):
         """This method passes through to self.conn.execute.
 
         :param sql: the parameterized sql to execute
